Monty Python's Flying Circus: Just the Words - Episode 6

# Episode Six

'It's the arts'
Johann Gambolputty.... von Hautkopf of Ulm
Non-illegal robbery
Vox pops
Crunchy frog
The dull life of a City stockbroker
Red Indian in theatre
Policemen make wonderful friends
A Scotsman on a horse
Twentieth-century vole

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| In the foreground we see a telephone. In the very distant background we see the 'It's' man. The telephone starts to ring. The 'It's' man runs towards the camera and the telephone (speeded up). He arrives at the telephone, picks up the reciever and is about to speak into the mouthpiece when he remembers the camera. He puts his hand over the mouthpiece and says to the camera:
It's Man | It's...
| He returns to the reciever. Animated opening titles. CAPTION: 'NEXT WEEK' CAPTION: 'HOW TO FLING AN OTTER' CAPTION: 'THIS WEEK' CAPTION: 'THE BBC ENTRY FOR THE ZINC STOAT OF BUDAPEST (CURRENT AFFAIRS)' CAPTION: 'THESE CAPTIONS COST 12/6D. EACH' Cut to presenter in studio. SUPERIMPOSED CAPTION: 'ARTHUR FIGGIS' Lose caption. Pause. CAPTION: 'THE SAME. A FEW SECONDS LATER' SUPERIMPOSED CAPTION: 'THAT'S £4.7.6 SO FAR ON CAPTIONS ALONE' SUPERIMPOSED CAPTION: 'NOT INCLUDING THAT ONE'
Man | (rushing in) I thought you did that so well Mr Figgis, could I have your autograph?
Figgis | You certainly can
| Presenter sign autograph. Part of his signature gets away (animation) and eventually leads us into the title: 'It's the Arts'. Classical music plays.
Figgis | Beethoven, Mozart, Chopin, Liszt, Brahms, Panties...I'm sorry...Schumann, Schubert, Mendelssohn and Bach. Names that will live for ever. But there is one composer whose name is never included with the greats. Why is it that the world never remembered the name of Johann Gambolputty de von Ausfern- schplenden- schlitter- crasscrenbon- fried- digger- dingle- dangle- dongle- dungle- burstein- von- knacker- thrasher- apple- banger- horowitz- ticolensic- grander- knotty- spelltinkle- grandlich- grumblemeyer- spelterwasser- kurstlich- himbleeisen- bahnwagen- gutenabend- bitte- ein- nürnburger- bratwustle- gerspurten- mitz- weimache- luber- hundsfut- gumberaber- shönedanker- kalbsfleisch- mittler- aucher von Hautkopft of Ulm? To do justice to this man, thought by many to be the greatest name in German Baroque music, we present a profile of Johann Gambolputty de von Ausfern- schplenden- schlitter- crasscrenbon- fried- digger- dingle- dangle- dongle- dungle- burstein- von- knacker- thrasher- apple- banger- horowitz- ticolensic- grander- knotty- spelltinkle- grandlich- grumblemeyer- spelterwasser- kurstlich- himbleeisen- bahnwagen- gutenabend- bitte- ein- nürnburger- bratwustle- gerspurten- mitz- weimache- luber- hundsfut- gumberaber- shönedanker- kalbsfleisch- mittler- aucher von Hautkopft of Ulm. We start with an interview with his only surviving relative Karl Gambolputty de von Ausfern... (fades out)
| Cut to old man sitting blanketed, in wheel-chair, as he speaks, intercut with shot of interviewer nodding and looking interested.
Karl | Oh ja. When I first met Johann Gambolputty de von Ausfern- schplenden- schlitter- crasscrenbon- fried- digger- dingle- dangle- dongle- dungle- burstein- von- knacker- thrasher- apple- banger- horowitz- ticolensic- grander- knotty- spelltinkle- grandlich- grumblemeyer- spelterwasser- kurstlich- himbleeisen- bahnwagen- gutenabend- bitte- ein- nürnburger- bratwustle- gerspurten- mitz- weimache- luber- hundsfut- gumberaber- shönedanker- kalbsfleisch- mittler- aucher von Hautkopft of Ulm, he was with his wife, Sarah Gambolputty de von...
Interviewer | (as he speaks intercut with shots of Karl nodding and trying to look interested) Yes, if I may just cut in on you there, Herr Gambolputty de von Ausfern- schplenden- schlitter- crasscrenbon- fried- digger- dingle- dangle- dongle- dungle- burstein- von- knacker- thrasher- apple- banger- horowitz- ticolensic- grander- knotty- spelltinkle- grandlich- grumblemeyer- spelterwasser- kurstlich- himbleeisen- bahnwagen- gutenabend- bitte- ein- nürnburger- bratwustle- gerspurten- mitz- weimache- luber- hundsfut- gumberaber- shönedanker- kalbsfleisch- mittler- aucher von Hautkopft of Ulm, and ask you - just quickly - if there's any particular thing that you remember about Johann Gambolputty de von Ausfern- schplenden- schlitter- crasscrenbon- fried- digger- dingle- dangle- dongle- dungle- burstein- von- knacker- thrasher- apple- banger- horowitz- ticolensic- grander- knotty- spelltinkle- grandlich- grumblemeyer- spelterwasser- kurstlich- himbleeisen- bahnwagen- gutenabend- bitte- ein- nürnburger- bratwustle- gerspurten- mitz- weimache- luber- hundsfut- gumberaber- shönedanker- kalbsfleisch- mittler- aucher von Hautkopft of Ulm?
| No response. He shakes the old man, then gets up and listens to his heart. Realizing with exasperation that his interviewee has died, he starts digging a grave. Cut back to presenter.
Figgis | A tribute to Johann Gambolputty...
| Cut to Viking.
Viking | ...de von Ausfern- schplenden- schlitter...
| Cut to weedy man in pullover with National Health specs.
Man | ...crasscrenbon- fried- digger- dingle- dangle- dongle...
| Cut to knight in armour.
Knight in Armour | ...dungle- burstein- von- knacker- thrasher...
| Cut to a succession of animated characters.
Mona Lisa | ...apple- banger- horowitz- ticolensic...
Lon Chaney | ...grander- knotty- spelltinkle...
Policeman | ...grandlich...
Pig | ...grumblemeyer...
Policeman | ...spelterwasser...
Boar | ...kurstlich- himbleeisen...
Botticelli Lover | ...bahnwagen- gutenabend...
Medieval Couple | ...bitte- ein- nürnburger...
Family Group | ...bratwustle...
Doctor | ...gerspurten...
Bishop & Saint | ...mitz- weimache- luber- hundsfut...
Two Dancers | ...gumberaber- shönedanker...
Three Naked Ladies | ...kalbsfleisch...
Cricket Team | ...mittler- aucher...
Policemen | ...von Hautkopft...
Figgis | ...of Ulm.
| ANIMATION: leading to: A garret room with a bare table. Around it are grouped four desperate-looking robbers. The Boss has a rolled-up map. One of the gang, the fifth, is looking out of the window.
Boss | All clear?
Fifth | All clear, boss.
Boss | (unfolding big map across table; talking carefuly) Right ... this is the plan then. At 10:45 .. you, Reg, collect me and Ken in the van, and take us round to the British Jewellery Centre in the High Street. We will arrive outside the British Jewellery Centre at 10:50 a of m. I shall then get out of the car, you Reg, take it and park it back here in Denver Street, right? At 10:51, I shall enter the British Jewellery Centre, where you, Vic, disguised as a customer, will meet me and hand me £5.18.3d. At 10:52, I shall approach the counter and purchase a watch costing £5.18.3d. I shall then give the watch to you, Vic. You'll go straight to Norman's Garage in East Street. You lads continue back up here at 10:56 and we rendezvous in the back room at the Cow and Sickle, at 11:15. All right, any questions?
Larry | We don't seem to be doing anything illegal.
Boss | What do you mean?
Larry | Well ... we're paying for the watch.
Boss | (patiently) Yes...
Larry | (hesitating) Well... why are we paying for the watch?
Boss | (heavily) They wouldn't give it to us if we didn't pay for it, would they... eh?
Larry | Look! I don't like this outfit.
Boss | Why not?
Larry | (at last feeling free to say what's on his mind) Well, we never break the bloody law.
| General consternation.
Boss | What d'you mean?
Larry | Well, look at that bank job last week.
Boss | What was wrong with that?
Larry | Well having to go in there with a mask on and ask for £15 out of my deposit account; that's what was wrong with it.
Boss | Listen! What are you trying to say, Larry?
Larry | Couldn't we just steal the watch, Boss
Boss | Oh, you dumb cluck! We spent weeks organizing this job. Reg rented a room across the road and filmed the people going in and out every day. Vic spent three weeks looking at watch catalogues...until he knew the price of each one backwards, and now I'm not going to risk the whole raid just for the sake of breaking the law.
Larry | Urr... couldn't we park on a double yellow line?
Boss | No!
Larry | Couldn't we get a dog to foul the foot...
Boss | No!
Reg | (suddenly going pale) 'Ere, Boss!
Boss | What's the matter with you?
Reg | I just thought... I left the car on a meter... and it's...
Boss | Overdue?
Reg | Yes, Boss.
Boss | How much?
Reg | (quaking) I dunno, Boss... maybe two ... maybe five minutes ...
Boss | Five minutes overdue. You fool! You fool! All right ... we've no time to lose. Ken - shave all your hair off, get your passport and meet me at this address in Rio de Janeiro Tuesday night. Vic - go to East Africa, have plastic surgery and meet me there. Reg - go to Canada and work your way south to Nicaragua by July. Larry - you stay here as front man. Give us fifteen minutes then blow the building up. All right, make it fast.
Larry | I can't blow the building up.
Boss | Why not?
Larry | It's illegal.
Boss | Oh bloody hell. Well we'd better give ourselves up then.
Reg | We can't, Boss.
Boss | Why not?
Reg | We haven't done anything illegal.
| Cut to film. Exterior of bank. Three bandits rush out with swag etc. One of them stops to talk to camera raising mask off head.
Bandit | No I think being illegal makes it more exciting.
Second Bandit | Yes, I agree. I mean, if you're going to go straight you might as well be a vicar or something.
| Cut to vicar, wheeling quickly round to reveal he has his hand in the restoration-fund box.
Vicar | What?
| Cut to chartered accountant.
Chartered Accountant | I agree. If there were fewer robbers there wouldn't be so many of them, numerically speaking.
| Cut to pepperpot.
Pepperpot | I think sexual ecstasy is over-rated.
| Cut to Scotsman.
Scotsman | Well, how very interesting, because I'm now made entirely of tin.
| Cut to Police Inspector Praline.
Praline | After a few more of these remarks, I shall be appearing in a sketch, so stay tuned.
| Cut to policeman.
Policeman | It's the uniform that puts them off, that and my bad breath.
| Cut to judge in full long wig and robes and a QC also wearing wig and robes.
Judge | (matter of factly) We like dressing up, yes...
| Cut to Inspector Praline.
Inspector Praline | Hello again. I am at present still on film, but in a few seconds I shall be appearing in the studio. Thank you.
| Cut to studio. A door opens. Inspector Praline looks round door.
Praline | (to camera) Hello. (he walks in followed by Superintendent Parrot and goes to desk) Mr Milton? You are sole proprietor and owner of the Whizzo Chocolate Company?
Milton | I am.
Praline | Superintendent Parrot and I are from the hygiene squad.We want to have a word with you about your box of chocolates entitled the Whizzo Quality Assortment.
Milton | Ah, yes.
Praline | (producing box of chocolate) If I may begin at the beginning. First there is the Cherry Fondue. This is extremely nasty, but we can't prosecute you for that.
Milton | Agreed.
Praline | Next we have number four, 'Crunchy Frog'.
Milton | An, yes.
Praline | Am I right in thinking there's a real frog in here?
Milton | Yes. A little one.
Praline | What sort of frog?
Milton | A dead frog.
Praline | Is it cooked?
Milton | No.
Praline | What, a raw frog?
| Superintendent Parrot looks increasingly queasy.
Milton | We use only the finest baby frogs, dew-picked and flown from Iraq, cleansed in the finest quality spring water, lightly killed, and then sealed in a succulent Swiss quintuple smooth treble cream milk chocolate envelope, and lovingly frosted with glucose.
Praline | That's as may be, but it's still a frog!
Milton | What else?
Praline | Well don't you even take the bones out?
Milton | If we took the bones out it wouldn't be crunchy would it?
Praline | Superintendent Parrot ate one of those.
Parrot | Excuse me a moment. (exits hurriedly)
Praline | Well, the Superintendent thought it was an almond whirl. People won't expect there to be a frog in there. They're bound to think it's some sort of mock frog.
Milton | (insulted) Mock frog? We use no artificial preservatives or additives of any kind!
Praline | Nevertheless, I must warn you that in future you should delete the words 'crunchy frog', and replace them with the legend, 'crunchy raw unboned real dead frog' if you want to avoid prosecution.
Milton | What about our sales?
Praline | I'm not interested in your sales! I have to protect the general public! Now what about this one. (superintendent enters) It was number five, wasn't it? (superintendent nods) Number five Ram's Bladder Cup. (exit superintendent) What sort of confection is this?
Milton | We use choicest juicy chunks of fresh Cornish ram's bladder, emptied, steamed, flavoured with sesame seeds, whipped into a fondue and garnished with lark's vomit.
Praline | Larks vomit?
Milton | Correct.
Praline | Well it don't say nothing about that here.
Milton | Oh yes it does, on the bottom of the box, after monosodium glutamate.
Praline | (looking) Wel I hardly think this is good enough. I think it's be more appropriate if the box bore a great red label warning lark's vomit.
Milton | Our sales would plummet!
Praline | Well why don't you move into more conventional areas of confectionary, like praline or lime cream; a very popular flavor, I'm lead to understand. (superintendent enters) I mean look at this one 'cockroach cluster', (superintendent exits) anthrax ripple! What's this one: 'spring surprise'?
Milton | Ah - now, that's our speciality - covered with darkest creamy chocolate. When you pop it into your mouth steel bolts spring out and plunge straight through both cheeks.
Praline | Well where's the pleasure in that? If people place a nice chocky in their mouth, they don't want their cheeks pierced. In any case this is an inadequate description of the sweetmeat. I shall have to ask you to accompany me to the station.
Milton | (getting up from the desk and being led away) It's a fair cop.
Praline | Stop talking to the camera.
Milton | I'm sorry.
| Supeintendent Parrot enters the room as Inspector Praline and Milton leave, and addresses the camera.
Parrot | If only the general public would take more care when buying its sweeties, it would reduce the number of man-hours lost to the nation and they would spend less time having their stomachs pumped and sitting around in public lavatories.
Announcer | The BBC would like to apologize for the extremely poor quality of the next announcement, only he's not at all well.
Parrot | We present 'The Dull Life of a City Stockbroker',
| Cut to a nice suburban street. Inside the house a stockbroker (Michael) is finishing his breakfast. His attractive wife looks on. He picks up his hat, rises, kisses her goodbye, and leaves. As he does so, she takes off her wrap and two men dressed only in briefs (Graham and Terry J) step out of the kitchen cupboard. In the front garden the stockbroker bids his neighbour (Graham) good morning; as he moves off a large African native throws an assegai, killing the neighbour. The stockbroker, not noticing this, moves on. A high street: he walks into a newsagents. Behind the counter a naked young lady gives him his newspaper. Taking his change without apparently noticing her he leaves. A bus queue: the stockbroker is at the head of it; there are four people behind him. As they wait, the Frankenstein monster comes up behind them and works his way along the queue, killing each member as he goes. He has just reached the stockbroker - who has not seen him - when the bus arrives and the stockbroker gets on. On the bus: all the other passengers are uniformed soldiers. The bus drives along a road past explosions and gunfire. A hand grenade comes through the window and lands on the seat next to the stockbroker. The soldiers leave the bus rapidly; the stockbroker calmly leaves the bus and walks down the street, in which the soldiers are engaged in a pitched battle. The stockbroker hails a taxi; it stops. No driver is visible. The stockbroker gets in and it drives off. In the stockbroker's office: a secretary is dead across her typewriter with a knife in her back; at the back of the office a pair of legs swing gently from the ceiling; a couple are snogging at his desk. Unconcerned, the stockbroker sits down. Furtively he looks round, then takes from the desk drawer a comic-book entitled 'Thrills and Adventure'. We see the frames of the comic strip. A Superman-type character and a girl are shrinking from an explosion. She is saying 'My God, his nose just exploded with enough force to destroy his kleenex'. In the next frame, the Superman character is saying 'If only I had a kleenex to lend him - or even a linen handkerchief - but these trousers...!! No back pocket!' In the frame beneath, he flies from side to side attempting to escape; finally he breaks through, bringing the two frames above down on himself. Cut to a picture of a safety curtain. An animated man come in front of it and says:
Man | Coming right up - the theatre sketch - so don't move!
| The front stalls of a theatre. It is a first night - a lot of people in dinner jackets etc. About three rows back there is a spare seat. A general rustle of programmes, chocolates and theatrical murmurs. Suddenly a Sioux Indian enters, clad only in loin cloth, wearing war paint and with a single strip of hair in the middle of his head and feather. He carries a bow and a quiver of arrows. He settles into the empty seat. The man next to him shifts uneasily and looks straight ahead. The Indian looks his neighbour up and down a couple of times.
Indian | (always speaking with full gestures) Me heap want see play. Me want play start heap soon.
| Man next to him nods.
Man | Yes well. I think it ... begins in a minute.
Indian | Me heap big fan Cicely Courtneidge.
Man | (highly embarrassed) Yes ... she's very good.
Indian | She fine actress ... she make interpretation heap subtle ... she heap good diction and timing ... she make part really live for Indian brave.
Man | Yes ... yes ... she's marvelous...
Indian | My father - Chief Running Stag - leader of mighty Redfoot tribe - him heap keen on Michael Denison and Dulcie Gray.
Man | (unwillingly drawn in) Do you go to the theatre a lot?
Indian | When moon high over prairie ... when wolf howl over mountain, when mighty wind roar through Yellow Valley, we go Leatherhead Rep - block booking, upper circle - whole tribe get it on 3/6d each.
Man | That's very good.
Indian | Stage Manager, Stan Wilson, heap good friend Redfoot tribe. After show we go pow-wow speakum with director, Sandy Camp, in snug bar of Bell and Compasses. Him mighty fine director. Him heap famous.
Man | Oh - I don't know him myself.
Indian | Him say Leatherhead Rep like do play with Redfoot tribe.
Man | Oh that's good...
Indian | We do 'Dial M for Murder'. Chief Running Elk - him kill buffalo with bare hands, run thousand paces when the sun is high - him play Chief Inspector Hardy - heap good fine actor.
Man | You do a lot of acting do you?
Indian | Yes. Redfoot tribe live by acting and hunting.
Man | You don't fight any more?
Indian | Yes! Redfoot make war! When Chief Yellow Snake was leader, and Mighty Eagle was in land of forefather, we fight Pawnee at Oxbow Crossing. When Pawnee steal our rehearsal copies of 'Reluctant Debutante' we kill fifty Pawnee - houses heap full every night. Heap good publicity.
| The lights start to dim. Auditorium chatter subsides.
Man | (visibly relieved) I think he's about to start now, thank God for that.
| They both look towards stage. The overture starts.
Indian | (leaning across) Paleface like eat chocolate? (proffers box)
Man | No, thank you very much.
Indian | (helping himself) Hmmm - crunchy frog - heap good.
| Cut to stage, house manager walks out in front of tabs. He is a very nice young man.
House Manager | Ladies and gentlemen. Before the play starts, I would like to apologize to you all, but unfortunately Miss Cicely Courtneidge is unable to appear, owing to...
| He is suddenly struck in the chest by first one arrow and then another. He crumbles to the ground revealing half a dozen in his back. The air is filled with war-whoops and drum beats and screams. Cut to a working-class kitchen.
Mum | (reading newspaper) D'you read that, Edgar?
Dad (Ian Davidson) | What's that dear?
Mum | There's been another Indian massacre at Dorking Civic Theatre.
Dad | About time too dear...
Mum | 'Those who were left alive at the end got their money back'.
Dad | That's what live theatre needs - a few more massacres...
Mum | 'The police are anxious to speak to anyone who saw the crime, ladies with large breasts, or just anyone who likes policemen.'
| Suddenly a policeman walks in between the couple and the camera.
Policeman | (to camera) Yes! Policemen make wonderful friends. So if you are over six feet tall and would like a friend, a pen friend, in the police force, here is the address to write to: 'Mrs Ena Frog, 8 Masonic Apron Street, Cowdenbeath'. Remember - policemen make wonderful friends. So write today and take advantage of our free officer. Thank you. And now for the next sketch.
| The policeman removes his helmet, shakes it, proffers it to mum at the table. She takes out a small folded bit of paper, opens and reads.
Mum | A Scotsman on a horse.
Policeman | For Mrs Emma Hamilton of Nelson, a Scotsman on a horse.
| A Scotsman (John) rides up to the camera and looks around puzzled. In long-shot we see him riding off. At a wee Scottish kirk another Scotsman (Michael) is waiting at the head of the aisle to be married. Intercut between first Scotsman galloping through the countryside and the wedding procession coming up the aisle. The wedding takes place; just as it finishes the first Scotsman rides up to the kirk and rushes in. The assembled congregation look at him in alarm as he surveys them; then he picks up Michael and carries him off. Cut to film of Women's Institute audience applauding.
| ANIMATION, which leads us to the 'Twentieth Century Vole' trademark. Cut to film producer's office. Six writers sitting round a table with one very impressive chair empty at the head of the table. They wait reverently. Suddenly the door of the room flies open and Larry Saltzberg, the film producer, walks in. The writers leap to their feet.
Larry | Good morning boys.
Writers | Good morning Mr Saltzberg.
| They run to help him into his chair.
Larry | (sitting) Sit down! Sit down! Sit down! Sit down! Now, boys, I want you to know that I think you are the best six writers in movies today. (the writers are overcome) I want you to know that I've had an idea for the next movie I'm going to produce and I want you boys to write it.
| The writers run and kiss him.
Writers | Thank you. Thank you.
Larry | Oh sit down! Sit down! Sit down! There'll be plenty of time for that later on. Now boys, here's my idea...
Third Writer | It's great!
Larry | You like it huh? (he looks round the table)
Writers | (catching on fast) Yeah, yeah, great! Really great. Fantastic. (first writer is the only one not having an orgasm about the idea)
Larry | (to first writer) Do you like it?
First Writer | (thrown) Yeah! Er ... yeah.
Larry | (still to first writer) What do you like best about it?
First Writer | Oh well you haven't told us... what it is yet...
Larry | WHAT!?
First Writer | (pointing at second writer) I like what he likes.
Larry | What do you like?
Second Writer | (pointing at third writer) I like what he likes.
Third Writer | (pointing at fourth writer) I like what he likes.
Fourth Writer | I like what he likes (pointing at fifth writer)
Fifth Writer | I just crazy about what he likes (pointing at sixth writer)
Larry | What do you like?
Sixth Writer (Ian Davidson) | I ... I ... I ... agree with them.
Larry | Good! Now we're getting somewhere. Now, here's the start of the movie ... I see snow! (writers applaud) White snow!
Fourth Writer | Think of the colours!
Larry | And in the snow, I see ... a tree!
Writers | (applauding) Yes! Yes!
Larry | Wait, wait I haven't finished yet.
Third Writer | There's more?
Larry | And by this tree, gentlemen, I see ... a dog!
Writers | Olé!
Larry | And gentlemen, this dog goes up to the tree, and he piddles on it.
Writers | Hallelujah!
Sixth Writer | Have we got a movie!
Fifth Writer | He tells it the way it is!
Fourth Writer | It's where it's at!
Third Writer | This is something else!
Second Writer | It's out of sight!
First Writer | (finding Larry staring at him) I like it, I like it.
Larry | (suspicious) Oh yeah?
First Writer | Yeah, yeah, I promise I like it
Fifth Writer | Sir, I don't know how to say this but I got to be perfectly frank. I really and truly believe this story of yours is the greatest story in motion-picture history.
Larry | Get out!
Fifth Writer | What?
Larry | If there's one thing I can't stand, it's a yes-man! Get out! (fifth writer leaves very fast, the others go very quiet) I'll see you never work again. (to sixth writer) What do you think?
Sixth Writer | Well... I...
Larry | Just because I have an idea it doesn't mean it's great. It could be lousy.
Sixth Writer | It could?
Larry | Yeah! What d'ya think?
Sixth Writer | It's lousy.
Larry | There you are, you see, he spoke his mind. He said my idea was lousy. It just so happens my idea isn't lousy so get out you goddam pinko subversive, get out! (sixth writer exits) You... (looking straight at fourth writer)
Fourth Writer | Well ... I think it's an excellent idea.
Larry | Are you a yes-man?
Fourth Writer | No, no, no, I mean there may be things against it.
Larry | You think it's lousy, huh?
Fourth Writer | No, no, I mean it takes time.
Larry | (really threatening) Are you being indecisive?
Fourth Writer | Yo. Nes. Perhaps. (runs out)
Larry | I hope you three gentlemen aren't going to be indecisive! (they try to hide under the table) What the hell are you doing under that table?
First Writer | We dropped our pencils.
Larry | Pencil droppers, eh?
Writers | No, no, no, no, no!
Larry | Right. Now I want your opinion of my idea ... (pointing at first writer) You...
First Writer | (quaking) Oh...
| First writer looks around and then faints.
Larry | Has he had a heart attack?
Second and Third Writers | Er...
Larry | If there's one thing I can't stand, it's people who have heart attacks.
First Writer | (recovering immediately) I feel fine now.
Larry | Well, what do you think?
Writers | Oh! Eh! You didn't ask me you asked him. He didn't ask me, he asked him. No, him.
Larry | I've changed my mind. I'm asking you, the one in the middle.
Second Writer | The one in the middle?
Larry | Yes, the one in the middle. (the phone rings) Hello, yes, yes, yes, yes, yes, yes, Dimitri ... (all jockey for position desperately trying to put the others in the middle and finish sitting on one chair) What the hell are you doing?
Second Writer | I'm thinking.
Larry | Get back in those seats immediately. (back to phone) Yes... (second writer is grabbed by the others and held in the middle chair; Larry finishes with the phone) Right you. The one in the middle, what do you think?
Second Writer | (panic) Er... er...
Larry | Come on!
Second Writer | Splunge.
Larry | Did he say splunge?
First and Third Writers | Yes.
Larry | What does splunge mean?
Second Writer | It means ... it's a great-idea-but-possibly-not-and-I'm-not-being-indecisive!
Larry | Good. Right . .. (to third writer) What do you think?
Third Writer | Er. Splunge?
Larry | OK...
First Writer | Yeah. Splunge for me too.
Larry | So all three of you think splunge, huh?
Writers | Yes!
Larry | Well now we're getting somewhere. No, wait. A new angle! In the snow, instead of the tree, I see Rock Hudson, and instead of the dog I see Doris Day and, gentlemen, Doris Day goes up to Rock Hudson and she kisses him. A love story. Intercourse Italian style. David Hemmings as a hippy Gestapo officer. Frontal nudity. A family picture. A comedy. And then when Doris Day's kissed Rock Hudson she says something funny like... (looks at third writer)
Third Writer | Er ... Good evening.
Larry | Doris Day's a comedienne, not a newsreader. Get out! (third writer runs) She says something funny like (looks at second writer)
Second Writer | Splunge?
Larry | That's the stupidest idea I ever heard. Get out! (second writer leaves) Doris Dog kisses Rock Tree and she says (looks at first writer)
First Writer | Er... er... er... I can't take it anymore. (runs out)
Larry | I like that! I like that, I can't take it any more, and then Rock Hudson says 'I'm a very rich film producer and I need a lobotomy' and then Doris Dog says 'I think you're very handsome and I'm going to take all my clothes off' and then Doris Dog turns into a yak and goes to the bathroom on David Lemming. No, wait, wait! (picks up phone) Hello, (cut to 'It's' man film with Larry continuing voice over) hello, hello, who are you? You're an out-of-work writer? Well, you're fired. Roll the credits. (here the credits do start to roll with Larry's voice continuing over) Produced by Irving C. Saltzberg Jnr. of Irving C. Saltzberg Productions Ltd. and Saltzberg Art Films, Oil, Real Estate, Banking and Prostitution Inc.
| The credits read: PRODUCED BY IRVING C. SALTZBERG JNR. AN IRVING C. SALTZBERG PRODUCTIONS LTD. AND SALTZBERG ARTFILMS, OIL, REAL ESTATE, BANKING AND PROSTITUTION INC. CO-PRODUCTION FROM AN ORIGINAL IDEA BY IRVING C. SALTZBERG JNR. WRITTEN BY IRVING C. SALTZBERG AND IRVING C. SALTZBERG ADDITIONAL MATERIAL BY IRVING C. SALTZBERG AND GRAHAM C. CHAPMANBERG JOHN C. CLEESEBERG TERRY C. JONESBERG MICHAEL C. PALINBERG TERRY C. GILLIAMBERG ERIC C. IDLEBERG ALSO APPEARING WAS IAN C. DAVIDSONBERG CREDITS BY IRVING C. SALTZBERG
| The technical credits continue in the same style.